@@ -16,6 +16,7 @@ setClass("GRangesList",
 
 setClassUnion("GenomicRangesORGRangesList", c("GenomicRanges", "GRangesList"))
 
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Validity.
 ###
@@ -45,6 +46,7 @@ setClassUnion("GenomicRangesORGRangesList", c("GenomicRanges", "GRangesList"))
 
 setValidity2("GRangesList", .valid.GRangesList)
 
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Constructors.
 ###
@@ -64,21 +66,6 @@ GRangesList <- function(...)
     relist(unlistData, PartitioningByEnd(listData))
 }
 
-### TODO: Use this in GenomicFeatures::transcriptLocs2refLocs() and remove
-### GenomicFeatures:::.normargExonStartsOrEnds().
-.normargListOfIntegers <- function(arg, sep, argname) 
-{
-    if (is.list(arg)) 
-        return(arg)
-    if (is(arg, "IntegerList")) 
-        return(as.list(arg))
-    if (is.character(arg)) 
-        return(strsplitAsListOfIntegerVectors(arg, sep=sep))
-    stop("'", argname, "' must be a list of integer vectors, ", 
-        "an IntegerList object,\n  or a character vector where ", 
-        "each element is a comma-separated list of\n  integers")
-}
-
 ### Typically, the field values will come from a file that needs to be loaded
 ### into a data.frame first.
 makeGRangesListFromFeatureFragments <- function(seqnames=Rle(factor()),
@@ -88,13 +75,13 @@ makeGRangesListFromFeatureFragments <- function(seqnames=Rle(factor()),
                                                 strand=character(0),
                                                 sep=",")
 {
-    fragmentStarts <- .normargListOfIntegers(fragmentStarts, sep,
-                                             "fragmentStarts")
+    fragmentStarts <- normargListOfIntegers(fragmentStarts, sep,
+                                            "fragmentStarts")
     nfrag_per_feature <- elementLengths(fragmentStarts)
     start <- unlist(fragmentStarts, recursive=FALSE, use.names=FALSE)
 
-    fragmentEnds <- .normargListOfIntegers(fragmentEnds, sep,
-                                           "fragmentEnds")
+    fragmentEnds <- normargListOfIntegers(fragmentEnds, sep,
+                                          "fragmentEnds")
     nend_per_elt <- elementLengths(fragmentEnds)
     if (length(nend_per_elt) != 0L) {
         if (length(nfrag_per_feature) == 0L)
@@ -105,8 +92,8 @@ makeGRangesListFromFeatureFragments <- function(seqnames=Rle(factor()),
     }
     end <- unlist(fragmentEnds, recursive=FALSE, use.names=FALSE)
 
-    fragmentWidths <- .normargListOfIntegers(fragmentWidths, sep,
-                                             "fragmentWidths")
+    fragmentWidths <- normargListOfIntegers(fragmentWidths, sep,
+                                            "fragmentWidths")
     nwidth_per_elt <- elementLengths(fragmentWidths)
     if (length(nwidth_per_elt) != 0L) {
         if (length(nfrag_per_feature) == 0L)
@@ -157,93 +144,21 @@ setMethod("updateObject", "GRangesList",
     }
 )
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Coercion.
-###
-
-.GRangesListAsdataframe <- function(x, row.names=NULL, optional=FALSE, ...)
-{
-    if (missing(row.names))
-        row.names <- names(x@unlistData)
-    if (is.null(names(x)))
-        element <- rep.int(seq_len(length(x)), elementLengths(x))
-    else
-        element <- rep.int(names(x), elementLengths(x))
-    data.frame(element = element,
-               as.data.frame(unlist(x, use.names = FALSE),
-                             row.names = row.names),
-               stringsAsFactors = FALSE)
-}
-setMethod("as.data.frame", "GRangesList", .GRangesListAsdataframe)
-
-.GRangesListAsCompressedIRangesList <- function(from)
-{
-    ans_ranges <- from@unlistData@ranges
-    ans_ranges@elementMetadata <- from@unlistData@elementMetadata
-    new("CompressedIRangesList",
-        unlistData=ans_ranges,
-        partitioning=from@partitioning,
-        elementMetadata=from@elementMetadata)
-}
-
-setAs("GRangesList", "CompressedIRangesList",
-    .GRangesListAsCompressedIRangesList
-)
-
-setAs("GRangesList", "IRangesList",
-    .GRangesListAsCompressedIRangesList
-)
-
-setAs("RangedDataList", "GRangesList",
-      function(from) GRangesList(lapply(from, as, "GRanges")))
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Accessor methods.
+### Accessors.
 ###
 
 setMethod("seqnames", "GRangesList",
     function(x)
-        new2("CompressedRleList",
-             unlistData = x@unlistData@seqnames, partitioning = x@partitioning,
-             check=FALSE))
-
-setMethod("ranges", "GRangesList",
-    function(x, ...)
-        new2("CompressedIRangesList",
-             unlistData = x@unlistData@ranges, partitioning = x@partitioning,
-             check=FALSE))
-
-setMethod("strand", "GRangesList",
-    function(x)
-        new2("CompressedRleList",
-             unlistData = x@unlistData@strand, partitioning = x@partitioning,
-             check=FALSE))
-
-.getElementMetadataList <- 
-    function(x, use.names=FALSE, level = c("between", "within"), ...)
-{
-    if (!isTRUEorFALSE(use.names))
-        stop("'use.names' must be TRUE or FALSE")
-    level <- match.arg(level)
-    if (level == "between") {
-        ans <- x@elementMetadata
-        if (use.names)
-            rownames(ans) <- names(x)
-    } else {
-        elementMetadata <- x@unlistData@elementMetadata
-        if (use.names)
-            rownames(elementMetadata) <- names(x@unlistData)
-        ans <-
-          new2("CompressedSplitDataFrameList", unlistData = elementMetadata,
-               partitioning = x@partitioning, check=FALSE)
+    {
+        unlisted_x <- unlist(x, use.names=FALSE)
+        relist(seqnames(unlisted_x), x)
     }
-    ans
-}
-setMethod("elementMetadata", "GRangesList", .getElementMetadataList)
+)
 
-setMethod("seqinfo", "GRangesList", function(x) seqinfo(x@unlistData))
-
-.replaceSeqnamesList <- function(x, value)
+### NOT exported but used in GenomicAlignments package.
+replaceSeqnamesList <- function(x, value)
 {
     if (!is(value, "AtomicList") ||
         !identical(elementLengths(x), elementLengths(value)))
@@ -257,7 +172,23 @@ setMethod("seqinfo", "GRangesList", function(x) seqinfo(x@unlistData))
     seqnames(x@unlistData) <- value
     x
 }
-setReplaceMethod("seqnames", "GRangesList", .replaceSeqnamesList)
+setReplaceMethod("seqnames", "GRangesList", replaceSeqnamesList)
+
+setMethod("ranges", "GRangesList",
+    function(x, use.mcols=FALSE)
+    {
+        if (!isTRUEorFALSE(use.mcols))
+            stop("'use.mcols' must be TRUE or FALSE")
+        unlisted_x <- unlist(x, use.names=FALSE)
+        unlisted_ans <- unlisted_x@ranges
+        if (use.mcols)
+            mcols(unlisted_ans) <- mcols(unlisted_x)
+        ans <- relist(unlisted_ans, x)
+        if (use.mcols)
+            mcols(ans) <- mcols(x)
+        ans
+    }
+)
 
 setReplaceMethod("ranges", "GRangesList",
     function(x, value) 
@@ -271,7 +202,82 @@ setReplaceMethod("ranges", "GRangesList",
     }
 )
 
-.replaceStrandList <- function(x, value)
+### Same as for CompressedIRangesList.
+setMethod("start", "GRangesList",
+    function(x, ...)
+    {
+        unlisted_x <- unlist(x, use.names=FALSE)
+        relist(start(unlisted_x), x)
+    }
+)
+
+setReplaceMethod("start", "GRangesList",
+    function(x, check = TRUE, value)
+    {
+        if (!is(value, "IntegerList") ||
+            !identical(elementLengths(x), elementLengths(value)))
+            stop("replacement 'value' is not an IntegerList with the same ",
+                 "elementLengths as 'x'")
+        value <- unlist(value, use.names = FALSE)
+        start(ranges(x@unlistData), check = check) <- value
+        x
+    }
+)
+
+### Same as for CompressedIRangesList.
+setMethod("end", "GRangesList",
+    function(x, ...)
+    {
+        unlisted_x <- unlist(x, use.names=FALSE)
+        relist(end(unlisted_x), x)
+    }
+)
+
+setReplaceMethod("end", "GRangesList",
+    function(x, check = TRUE, value)
+    {
+        if (!is(value, "IntegerList") ||
+            !identical(elementLengths(x), elementLengths(value)))
+            stop("replacement 'value' is not an IntegerList with the same ",
+                 "elementLengths as 'x'")
+        value <- unlist(value, use.names = FALSE)
+        end(ranges(x@unlistData), check = check) <- value
+        x
+    }
+)
+
+### Same as for CompressedIRangesList.
+setMethod("width", "GRangesList",
+    function(x)
+    {
+        unlisted_x <- unlist(x, use.names=FALSE)
+        relist(width(unlisted_x), x)
+    }
+)
+
+setReplaceMethod("width", "GRangesList",
+    function(x, check = TRUE, value)
+    {
+        if (!is(value, "IntegerList") ||
+            !identical(elementLengths(x), elementLengths(value)))
+            stop("replacement 'value' is not an IntegerList with the same ",
+                 "elementLengths as 'x'")
+        value <- unlist(value, use.names = FALSE)
+        width(ranges(x@unlistData), check = check) <- value
+        x
+    }
+)
+
+setMethod("strand", "GRangesList",
+    function(x)
+    {
+        unlisted_x <- unlist(x, use.names=FALSE)
+        relist(strand(unlisted_x), x)
+    }
+)
+
+### NOT exported but used in GenomicAlignments package.
+replaceStrandList <- function(x, value)
 {
     if (!is(value, "AtomicList") ||
         !identical(elementLengths(x), elementLengths(value)))
@@ -286,9 +292,31 @@ setReplaceMethod("ranges", "GRangesList",
     strand(x@unlistData) <- value
     x
 }
-setReplaceMethod("strand", "GRangesList", .replaceStrandList)
+setReplaceMethod("strand", "GRangesList", replaceStrandList)
 
-.replaceElementMetadataList <- 
+### NOT exported but used in GenomicAlignments package.
+getElementMetadataList <- 
+    function(x, use.names=FALSE, level = c("between", "within"), ...)
+{
+    if (!isTRUEorFALSE(use.names))
+        stop("'use.names' must be TRUE or FALSE")
+    level <- match.arg(level)
+    if (level == "between") {
+        ans <- x@elementMetadata
+        if (use.names)
+            rownames(ans) <- names(x)
+        return(ans)
+    }
+    unlisted_x <- unlist(x, use.names=FALSE)
+    unlisted_ans <- unlisted_x@elementMetadata
+    if (use.names)
+        rownames(unlisted_ans) <- names(unlisted_x)
+    relist(unlisted_ans, x)
+}
+setMethod("elementMetadata", "GRangesList", getElementMetadataList)
+
+### NOT exported but used in GenomicAlignments package.
+replaceElementMetadataList <- 
     function(x, level = c("between", "within"), ..., value)
 {
         level <- match.arg(level)
@@ -322,9 +350,12 @@ setReplaceMethod("strand", "GRangesList", .replaceStrandList)
     }
     x
 }
-setReplaceMethod("elementMetadata", "GRangesList", .replaceElementMetadataList)
+setReplaceMethod("elementMetadata", "GRangesList", replaceElementMetadataList)
 
-.replaceSeqinfoList <- function(x, new2old=NULL, force=FALSE, value)
+setMethod("seqinfo", "GRangesList", function(x) seqinfo(x@unlistData))
+
+### NOT exported but used in GenomicAlignments package.
+replaceSeqinfoList <- function(x, new2old=NULL, force=FALSE, value)
 {
     if (!is(value, "Seqinfo"))
         stop("the supplied 'seqinfo' must be a Seqinfo object")
@@ -338,75 +369,54 @@ setReplaceMethod("elementMetadata", "GRangesList", .replaceElementMetadataList)
     seqinfo(x@unlistData, new2old=new2old) <- value
     x
 }
-setReplaceMethod("seqinfo", "GRangesList", .replaceSeqinfoList)
+setReplaceMethod("seqinfo", "GRangesList", replaceSeqinfoList)
 
 setMethod("score", "GRangesList", function(x) {
   mcols(x)$score
 })
 
+setReplaceMethod("score", "GRangesList", function(x, value) {
+  mcols(x)$score <- value
+  x
+})
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### RangesList methods.
+### Coercion.
 ###
 
-setMethod("start", "GRangesList",
-    function(x, ...)
-        new2("CompressedIntegerList",
-             unlistData = start(x@unlistData@ranges),
-             partitioning = x@partitioning, check=FALSE))
+### NOT exported but used in GenomicAlignments package.
+GRangesListAsdataframe <- function(x, row.names=NULL, optional=FALSE, ...)
+{
+    if (missing(row.names))
+        row.names <- names(x@unlistData)
+    if (is.null(names(x)))
+        element <- rep.int(seq_len(length(x)), elementLengths(x))
+    else
+        element <- rep.int(names(x), elementLengths(x))
+    data.frame(element = element,
+               as.data.frame(unlist(x, use.names = FALSE),
+                             row.names = row.names),
+               stringsAsFactors = FALSE)
+}
+setMethod("as.data.frame", "GRangesList", GRangesListAsdataframe)
 
-setMethod("end", "GRangesList",
-    function(x, ...)
-        new2("CompressedIntegerList",
-             unlistData = end(x@unlistData@ranges),
-             partitioning = x@partitioning, check=FALSE))
-
-setMethod("width", "GRangesList",
-    function(x)
-        new2("CompressedIntegerList",
-             unlistData = width(x@unlistData@ranges),
-             partitioning = x@partitioning, check=FALSE))
-
-setReplaceMethod("start", "GRangesList",
-    function(x, check = TRUE, value)
-    {
-        if (!is(value, "IntegerList") ||
-            !identical(elementLengths(x), elementLengths(value)))
-            stop("replacement 'value' is not an IntegerList with the same ",
-                 "elementLengths as 'x'")
-        value <- unlist(value, use.names = FALSE)
-        start(ranges(x@unlistData), check = check) <- value
-        x
-    }
+setAs("GRangesList", "CompressedIRangesList",
+    function(from) ranges(from, use.mcols=TRUE)
+)
+setAs("GRangesList", "IRangesList",
+    function(from) ranges(from, use.mcols=TRUE)
+)
+setAs("GRangesList", "RangesList",
+    function(from) ranges(from, use.mcols=TRUE)
 )
 
-setReplaceMethod("end", "GRangesList",
-    function(x, check = TRUE, value)
-    {
-        if (!is(value, "IntegerList") ||
-            !identical(elementLengths(x), elementLengths(value)))
-            stop("replacement 'value' is not an IntegerList with the same ",
-                 "elementLengths as 'x'")
-        value <- unlist(value, use.names = FALSE)
-        end(ranges(x@unlistData), check = check) <- value
-        x
-    }
-)
+setAs("RangedDataList", "GRangesList",
+      function(from) GRangesList(lapply(from, as, "GRanges")))
 
-setReplaceMethod("width", "GRangesList",
-    function(x, check = TRUE, value)
-    {
-        if (!is(value, "IntegerList") ||
-            !identical(elementLengths(x), elementLengths(value)))
-            stop("replacement 'value' is not an IntegerList with the same ",
-                 "elementLengths as 'x'")
-        value <- unlist(value, use.names = FALSE)
-        width(ranges(x@unlistData), check = check) <- value
-        x
-    }
-)
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Vector methods.
+### Subsetting.
 ###
 
 .sBracketSubsetGRList <- function(x, i, j, ..., drop)
@@ -482,16 +492,24 @@ setReplaceMethod("[", "GRangesList", .sBracketReplaceGRList)
 }
 setReplaceMethod("[[", "GRangesList", .dBracketReplaceGRList)
 
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Going from GRanges to GRangesList with extractList() and family.
+###
+
+setMethod("relistToClass", "GRanges", function(x) "GRangesList")
+
+setMethod("splitAsListReturnedClass", "GRanges",
+    function(x) {.Deprecated("relistToClass"); "GRangesList"}
+)
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### show method.
 ###
 
-setMethod("show", "GRangesList",
-    function(object)
-        .showList(object, showGenomicRanges, TRUE)
-)
-
-.showList <- function(object, showFunction, with.classinfo, ...)
+### NOT exported but used in GenomicAlignments package.
+showList <- function(object, showFunction, with.classinfo, ...)
 {
     k <- length(object)
     cumsumN <- cumsum(elementLengths(object))
@@ -553,6 +571,12 @@ setMethod("show", "GRangesList",
     showSeqlengths(object)
 }
 
+setMethod("show", "GRangesList",
+    function(object)
+        showList(object, showGenomicRanges, TRUE)
+)
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Deconstruction/reconstruction of a GRangesList into/from a GRanges
 ### object.
@@ -634,64 +658,3 @@ reconstructGRLfromGR <- function(gr, x)
     ans
 }
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### "map" methods. 
-### 
-
-.listCumsum <- function(x) {
-  x_unlisted <- unlist(x, use.names=FALSE)
-  x_cumsum <- cumsum(x_unlisted)
-  x_part <- PartitioningByWidth(elementLengths(x))
-  x_cumsum - rep(x_cumsum[start(x_part)] - x_unlisted[start(x_part)],
-                 width(x_part))
-}
-
-.listCumsumShifted <- function(x) {
-  cs <- .listCumsum(x)
-  shifted <- c(0L, head(cs, -1))
-  shifted[start(PartitioningByWidth(elementLengths(x)))] <- 0L
-  shifted
-}
-
-.orderElementsByTranscription <- function(x) {
-  gr <- unlist(x, use.names = FALSE)
-  gr <- gr[order(togroup(x), start(gr))]
-  part <- PartitioningByWidth(x)
-  neg <- strand(gr)[start(part)] == "-"
-  ord <- IRanges:::mseq(ifelse(neg, end(part), start(part)),
-                          ifelse(neg, start(part), end(part)))
-  relist(gr[ord], x)
-}
-
-setMethod("map", c("GenomicRanges", "GRangesList"), function(from, to) {
-  ## make sure 'to' is properly sorted by strand
-  to <- .orderElementsByTranscription(to)
-  
-  ## find overlaps
-  gr <- unlist(to, use.names=FALSE)
-  ol <- findOverlaps(from, gr, type = "within")
-  shits <- subjectHits(ol)
-  qhits <- queryHits(ol)
-  local <- ranges(from)[qhits]
-  bounds <- ranges(gr)[shits]
-  
-  ## location wrt start of coding region 
-  neg <- as.vector(strand(gr)[shits] == "-")
-  local[!neg] <- shift(local[!neg], - start(bounds)[!neg])
-  local[neg] <- IRanges(end(bounds)[neg] - end(local)[neg],
-                        width = width(local)[neg])
-  
-  ## location wrt transcript
-  cumsums <- .listCumsumShifted(width(to))
-  local <- shift(local, 1L + cumsums[shits])
-  
-  toInd <- togroup(to)[shits]
-  matching <- new("Hits",
-                  queryHits = qhits, subjectHits = toInd,
-                  queryLength = length(from), subjectLength = length(to))
-  space <- names(to)[toInd]
-  if (is.null(space))
-    space <- as.character(seq_len(length(to))[subjectHits(ol)])
-  new("RangesMapping", hits = matching, ranges = local,
-      space = Rle(space))
-})
