@@ -400,5 +400,47 @@ test_findOverlaps_with_circular_sequences <- function()
                    subjectHits = unname(matchMatrix3[ , 2L]),
                    queryLength = 4L, subjectLength = 4L)
     checkIdentical(target3, current3)
-}
 
+    ## type = "within"
+    q0 <- GRanges("A", IRanges(c(11, 5, 4, 11, 11, 4), 
+                     c(30, 30, 30, 50, 51, 51)))
+    s0 <- GRanges("A", IRanges(5, width=46))
+    s0@seqinfo <- Seqinfo(seqnames="A", seqlengths=100, isCircular=TRUE)
+    ## sanity check with linear shift 
+    fo0 <- findOverlaps(q0, s0, type="within")
+    expected <- c(1L, 2L, 4L)
+    checkIdentical(queryHits(fo0), expected)
+    A=90
+    q1 <- shift(q0, A)
+    s1 <- shift(s0, A)
+    fo1 <- findOverlaps(q1, s1, type="within")
+    checkIdentical(queryHits(fo1), expected)
+    ## circular shift 
+    n1=-1; n2=0
+    q2 <- shift(q0, A + 100 * n1)
+    s2 <- shift(s0, A + 100 * n2)
+    fo1 <- findOverlaps(q1, s1, type="within")
+    checkIdentical(queryHits(fo1), expected)
+
+    ## With A of length 8 --> range 3 is within range 2 
+    gr <- GRanges(seqnames=rep.int("A", 4),
+                  ranges=IRanges(start=c(2, 4, 6, 8), width=c(3, 3, 3, 5)))
+    gr@seqinfo <- Seqinfo(seqnames="A", seqlengths=8, isCircular=TRUE)
+    current4 <- findOverlaps(gr, gr, type="within")
+    matchMatrix4 <- matrix(c(1L, 1L, 2L, 3L, 4L, 
+                             1L, 4L, 2L, 3L, 4L), ncol = 2,
+                           dimnames = list(NULL, c("queryHits", "subjectHits")))
+    target4 <- new("Hits",
+                   queryHits = unname(matchMatrix4[ , 1L]),
+                   subjectHits = unname(matchMatrix4[ , 2L]),
+                   queryLength = 4L, subjectLength = 4L)
+    checkIdentical(target4, current4)
+    ## With A of length 9 --> range 3 is not within range 2 
+    gr@seqinfo <- Seqinfo(seqnames="A", seqlengths=9, isCircular=TRUE)
+    current5 <- findOverlaps(gr, gr, type="within")
+    target5 <- new("Hits",
+                   queryHits = unname(matchMatrix2[ , 1L]),
+                   subjectHits = unname(matchMatrix2[ , 2L]),
+                   queryLength = 4L, subjectLength = 4L)
+    checkIdentical(target5, current5)
+}
